@@ -27,6 +27,7 @@ var entries = []types.Entry{
 		DNSRCode:  "NOERROR",
 		DNSRData:  "10.0.0.12",
 		DNSType:   "answer",
+		Iface:     "enp2s0f1",
 		FlowID:    "4711",
 	},
 	types.Entry{
@@ -41,6 +42,8 @@ var entries = []types.Entry{
 		HTTPHost:   "api.icndb.com",
 		HTTPUrl:    `/jokes/random?firstName=Chuck&lastName=Norris&limitTo=[nerdy]`,
 		HTTPMethod: `GET`,
+		Iface:      "enp2s0f1",
+		AppProto:   "http",
 		FlowID:     "2323",
 	},
 	types.Entry{
@@ -55,6 +58,7 @@ var entries = []types.Entry{
 		HTTPHost:   "foobar",
 		HTTPUrl:    `/scripts/wpnbr.dll`,
 		HTTPMethod: `POST`,
+		Iface:      "enp2s0f1",
 		FlowID:     "2134",
 	},
 }
